@@ -35,7 +35,7 @@ int fu_get_param (int argc, char *argv[], fpstate *fpptr)
             fp_msg ("Error: internal initialization error\n"); exit (-1);
         }
 
-	tile[0] = (char) NULL;
+	tile[0] = 0;
 
         /* by default, .fz suffix characters to be deleted from compressed file */
 	fpptr->delete_suffix = 1;
@@ -106,6 +106,17 @@ int fu_get_param (int argc, char *argv[], fpstate *fpptr)
 	    fu_usage (); exit (-1);
         }
 
+	if (fpptr->to_stdout && (fpptr->outfile[0] || fpptr->prefix[0]) ) {
+
+	    fp_msg ("Error: -S option may not be used with -P or -O\n");
+	    fu_usage (); exit (-1);
+        }
+
+	if (fpptr->outfile[0] && fpptr->prefix[0] ) {
+	    fp_msg ("Error: -P and -O options may not be used together\n");
+	    fu_usage (); exit (-1);
+        }
+
 	if (iarg >= argc) {
 	    fp_msg ("Error: no FITS files to uncompress\n");
 	    fu_usage (); exit (-1);
