@@ -659,12 +659,12 @@ int ffgclk( fitsfile *fptr,   /* I - FITS file pointer                       */
 */
 {
     double scale, zero, power, dtemp;
-    int tcode, maxelem, hdutype, xcode, decimals;
+    int tcode, maxelem2, hdutype, xcode, decimals;
     long twidth, incre;
     long ii, xwidth, ntodo;
     int convert, nulcheck, readcheck = 0;
     LONGLONG repeat, startpos, elemnum, readptr, tnull;
-    LONGLONG rowlen, rownum, remain, next, rowincre;
+    LONGLONG rowlen, rownum, remain, next, rowincre, maxelem;
     char tform[20];
     char message[81];
     char snull[20];   /*  the FITS null value if reading from ASCII table  */
@@ -706,9 +706,10 @@ int ffgclk( fitsfile *fptr,   /* I - FITS file pointer                       */
         readcheck = -1;  /* don't do range checking in this case */
 
     if ( ffgcprll( fptr, colnum, firstrow, firstelem, nelem, readcheck, &scale, &zero,
-         tform, &twidth, &tcode, &maxelem, &startpos, &elemnum, &incre,
+         tform, &twidth, &tcode, &maxelem2, &startpos, &elemnum, &incre,
          &repeat, &rowlen, &hdutype, &tnull, snull, status) > 0 )
          return(*status);
+    maxelem = maxelem2;
 
     incre *= elemincre;   /* multiply incre to just get every nth pixel */
 
@@ -747,7 +748,7 @@ int ffgclk( fitsfile *fptr,   /* I - FITS file pointer                       */
     convert = 1;
     if (tcode == TLONG)           /* Special Case:                        */
     {                             /* no type convertion required, so read */
-        maxelem = (int) nelem;          /* data directly into output buffer.    */
+        maxelem = nelem;          /* data directly into output buffer.    */
 
         if (nulcheck == 0 && scale == 1. && zero == 0.)
             convert = 0;  /* no need to scale data or find nulls */
@@ -1811,7 +1812,7 @@ int fffstrint(char *input,        /* I - array of values to be converted     */
             cptr++;
         }
 
-        if (*cptr == '.')              /* check for decimal point */
+        if (*cptr == '.' || *cptr == ',')       /* check for decimal point */
         {
           decpt = 1;       /* set flag to show there was a decimal point */
           cptr++;
