@@ -53,6 +53,7 @@
 #define fits_null_check     ffnchk
 #define fits_make_keyn      ffkeyn
 #define fits_make_nkey      ffnkey
+#define fits_make_key       ffmkky
 #define fits_get_keyclass   ffgkcl
 #define fits_get_keytype    ffdtyp
 #define fits_get_inttype    ffinttyp
@@ -554,6 +555,7 @@
 #define fits_modify_vector_len  ffmvec
 
 #define fits_read_img_coord ffgics
+#define fits_read_img_coord_version ffgicsa
 #define fits_read_tbl_coord ffgtcs
 #define fits_pix_to_world ffwldp
 #define fits_world_to_pix ffxypx
